@@ -24,7 +24,7 @@ class HVAC(object):
         'fan': [HEAT_PUMP['fan']],
         'heat': [HEAT_PUMP['fan'], HEAT_PUMP['compressor']],
         '_cool': [HEAT_PUMP['reversing_valve']],
-        'cool': [HEAT_PUMP['fan'], HEAT_PUMP['compressor']],
+        'cool': [HEAT_PUMP['fan'], HEAT_PUMP['compressor'], HEAT_PUMP['reversing_valve']],
         'aux': [HEAT_PUMP['fan'], HEAT_PUMP['compressor'], HEAT_PUMP['aux']],
         'boost': [HEAT_PUMP['aux']],
         'emergency': [HEAT_PUMP['fan'], HEAT_PUMP['aux']],
@@ -75,7 +75,7 @@ class HestiaPi(Sensor):
         # container to store temperature history
         self.temperature_history = []
         # Minimum temperature rate of change over 4 measurements
-        self.minimum_temp_rate_of_change = .05
+        self.minimum_temp_rate_of_change = -0.25
         # super(HestiaPi, self).__init__(name, None, topic, 'climate', 'HestiaPi')
         # put thermostat into test mode. i.e. don't trigger HVAC commands
         self.dry_run = kwargs.get('dry_run')
@@ -164,12 +164,13 @@ class HestiaPi(Sensor):
                 if mode not in [HVAC.FAN, HVAC.BOOST]:
                     self.active_start_time = pendulum.now()
 
-                self._modes[mode].on()
-
                 if mode == HVAC.COOL:
+                    self._modes['heat'].on()
                     # delay reversing valve turn on before cooling starts
                     time.sleep(15)
                     self._modes['_cool'].on()
+                else:
+                    self._modes[mode].on()
                     
                 # confirm mode change
                 if mode == self.hvac_state: # TODO if boosting then only check boosting pin is active
@@ -180,9 +181,9 @@ class HestiaPi(Sensor):
             elif state == HVAC.OFF:
                 self._modes[mode].off()
                 
-                if mode == HVAC.COOL:
-                    time.sleep(3)
-                    self._modes['_cool'].off()
+                # if mode == HVAC.COOL:
+                #     time.sleep(3)
+                #     self._modes['_cool'].off()
 
                 if mode not in [HVAC.FAN, HVAC.BOOST]:
                     self.active_start_time = None
@@ -289,7 +290,7 @@ class HestiaPi(Sensor):
         if self.active:
             self.temperature_history.append(self.temperature)
             logging.debug('Temperature history = {}'.format(self.temperature_history))
-            if len(self.temperature_history) > 3: # how many readings should we keep track of. 4 is ~20 minutes.
+            if len(self.temperature_history) > 6: # how many readings should we keep track of. 4 is ~20 minutes.
                 self.temperature_history.pop(0)
 
     @property
